%
% Modal design of the initial controller
%
clear;
%
load open_loop_model;
sys=sys_open_loop(feedback_outputs,feedback_inputs);
[a,b,c,d]=ssdata(sys);
%
% Modal design
%
lambda=input2('Degree of stability (a positive value please): ',1);
warning off;
K=lqr(a+lambda*eye(size(a)),b,zeros(size(a)),eye(size(b,2)));
L=lqr(a'+lambda*eye(size(a)),c',zeros(size(a)),eye(size(c,1)));
warning on;
L=L';
%
% Visualization of the closed loop poles
%
e_obs=eig(a-L*c);
e_sf=eig(a-b*K);
e_ol=eig(sys_open_loop);
for i=1:2
  figure(i);
  clf;
  plot(real(e_ol),imag(e_ol),'go',real(e_sf),imag(e_sf),'r+',real(e_obs),imag(e_obs),'bx');
  title(' Open loop (go), state-feedback (r+) and observer (bx) poles');
end
figure(2);
sgrid([0.01:0.01:0.1 0.2:0.1:0.9],[]);
axis([-5 0 0 30]);
%
% Computation of the feedback controller K(s)
%
sys_Q=ss([],[],[],zeros(size(d,2),size(d,1)));
sys_K=comp_controller(sys_open_loop,feedback_inputs,feedback_outputs,K,L,sys_Q);
%
% Computation of a fine frequency gridding between 5 and 25 rad/s
%
valid=[];
valid.puls=linspace(5,25,50);
valid.cxi=0.3;
valid.range=0.1;
valid.N=10;
puls_valid=comp_puls_valid(sys_open_loop,feedback_inputs,feedback_outputs,K,L,sys_Q,[],valid);
list=find((puls_valid>=5)&(puls_valid<=25));
puls_valid=puls_valid(list);
%
% Computation of the closed loop
%
% In the context of our example, we focus on the closed loop transfer function 
% between the 2 additive disturbances on the inputs (dp,dq) used by the feedback
% controller and the acceleration output ny
%
sys_cl=feedback(sys_open_loop,sys_K,feedback_inputs,feedback_outputs,+1);
e=eig(sys_cl);
if max(real(e))>=0 error('SCRIPT_1_DESIGN_INITIAL_CONTROLLER: the closed loop should be stable !?'); end
sys_cl=sys_cl(1,3:4);
freq_resp_cl=freqresp(sys_cl,puls_valid);
%
% We compare the frequency responses with the open loop ones, between (dp,dq) and ny
%
freq_resp_ol=freqresp(sys_open_loop(1,1:2),puls_valid);
%
figure(3);
clf;
plot(puls_valid,squeeze(abs(freq_resp_cl(1,1,:))),'g-',puls_valid,squeeze(abs(freq_resp_ol(1,1,:))),'b--');
title('1st input --> ny (open loop = b--)');
%
figure(4);
clf;
plot(puls_valid,squeeze(abs(freq_resp_cl(1,2,:))),'g-',puls_valid,squeeze(abs(freq_resp_ol(1,2,:))),'b--');
title('2d input --> ny (open loop = b--)');
%
save obs_state_feedback sys_open_loop feedback_outputs feedback_inputs K L sys_K sys_Q;
%
fprintf('\n *** Controller saved in obs_state_feedback.mat ***\n\n');
