%
% Computation of the Youla parameterization.
%
% A file youla_file.mat is produced.
%
clear;
%
load obs_state_feedback;
%
% specif_inputs  = list of plant inputs  used for the design specifications
% (these inputs cannot correspond to inputs used by the feedback controller)
% (Here, the first 2 plant inputs are used by the feedback controller,
%  and the other 2 ones are used for the design spec.)
%
% specif_outputs = list of plant outputs used for the design specifications
% Here, all plant outputs are selected
%
specif_inputs =3:4;
specif_outputs=1:9;
%
% Computation of an augmented controller, with additional inputs and outputs
% corresponding to the interconnection with a Youla parameter.
%
% The first I/O of sys_K_aug classically correspond to the feedback
% with the plant I/O. The last I/O of sys_K_aug correspond to the interconnection
% with a Youla parameter.
%
sys_K_aug=comp_controller_aug(sys_open_loop,feedback_inputs,feedback_outputs,K,L);
%
nu=length(feedback_inputs);
ny=length(feedback_outputs);
%
% Conputation of the interconnection of the open loop plant
% with the augmented initial controller
%
nut=size(sys_open_loop,2);
nyt=size(sys_open_loop,1);
[acl,bcl,ccl,dcl]=linmod('sys_closed_loop'); % This file should be modified if specif_inputs and specif_outputs were modified
%
e=eig(acl);
if max(real(e))>=0
  error('SCRIPT_2_CALC_YOULA_PARAMETERIZATION: the initial controller is not stabilizing !');
end
%
youla=[];
youla.sys_T=ss(acl,bcl,ccl,dcl);
%
% T(s) = [T1(s) T2(s); T3(s) 0].
%
% The first I/O of T(s) correspond to the I/O used by the design specifications.
% The last  I/O of T(s) correspond to the interconnection with the Youla parameter Q(s).
%
nw=length(specif_inputs);
nz=length(specif_outputs)+2;
youla.idxI1=1:nw;
youla.idxI2=(nw+1):(nw+nu);
youla.idxO1=1:nz;
youla.idxO2=(nz+1):(nz+ny);
%
% Additional computation of a fine frequency gridding for validation and H2 specifications.
%
% valid.puls is a first generic frequency gridding
% This gridding is refined around the frequencies of the flexible modes
% (see the help of comp_puls_valid.m)
%
valid=[];
valid.puls=[0 logspace2(1e-2,1e3,200)];
valid.cxi=0.3;
valid.range=0.1;
valid.N=10;
youla.puls_valid=comp_puls_valid(sys_open_loop,feedback_inputs,feedback_outputs,K,L,sys_Q,[],valid);
%
save youla_file.mat youla sys_Q specif_inputs specif_outputs;
%
fprintf('\n\n *** Youla parameterization saved in youla_file.mat ***\n\n');
