function [sys_Q,alfa_opt,OK_design,puls_valid,puls_syn,subgradients,list_critical_models]=youla_lft_design_one_shot(youla,...
         sys_Q0,tab_sys_Q,tab_delta,tab_nbr_variables,tuning,puls_syn,specif,puls_specif,list_poles,valid,...
	     i_first_critical_model,is_linearity_test,first_figure,subgradients)
%
% call:  [sys_Q,alfa_opt,OK_design,puls_valid,puls_syn,subgradients,list_critical_models]=youla_lft_design_one_shot(youla,...
%        sys_Q0,tab_sys_Q,tab_delta,tab_nbr_variables,tuning,puls_syn,specif,puls_specif,list_poles,valid,...
%	     i_first_critical_model,is_linearity_test,first_figure,subgradients)
%
% convex multi-model design of a feedback LFT controller for an open loop LFT plant.
%
% youla describes the initial LFT closed loop:
% * youla.sys_lft describes the upper LFT model F_u(M(s),Delta)
% - youla.sys_lft.A
% - youla.sys_lft.B1
% - youla.sys_lft.B2
% - youla.sys_lft.C1
% - youla.sys_lft.C2
% - youla.sys_lft.D11
% - youla.sys_lft.D12
% - youla.sys_lft.D21
% - youla.sys_lft.D22
% For example, the poles of the LFT model are determined by A, B1, C1 and D11.
% See calc_lft_at_one_point.m for more details.
% * youla.idxI1 and youla.idxO1: list of I/O used for the design specifications.
% * youla.idxI2 and youla.idxO2: list of I/O used for the interconnection with Q(s).
% Caution ! youla.idx* refers to the I/O of F_u(M(s),Delta), not to those of M(s).
% * youla.blk describes the structure of Delta (musyn format).
%
% It is assumed that when connecting M(s) to Delta and Q(s), the affine form
% T1(s,Delta) + T2(s,Delta) Q(s) T3(s,Delta) is well obtained.
% This property will be checked inside the routine.
%
% Q(s) = Q_0(s) + \sum_i \theta_i Q_i(s), where the \theta_i are the optimization parameters.
% sys_Q0 is a state-space representation of  Q_0(s).
% tab_sys_Q{i} is a state-space representation of Q_i(s).
%
% Q(s) does not depend on Delta !
%
% tab_delta defines the gridding of design models.
% tab_delta(i,:) = value of the scheduling parameters for model # i. 
%
% tab_nbr_variables is a row vector containing an increasing number of optimisation variables.
% If tab_nbr_variables = [10 20 30], then the optimization is performed w.r.t. the first 10
% optimisation variables, then w.r.t. the first 20 ones, and last w.r.t. to all 30 ones.
% figure(2000) is produced if length(tab_nbr_variables) > 1.
% For a one-shot design, define tab_nbr_variables = length(tab_sys_Q);
%
% see optim_new.m for "tuning", noting that 3 additional parameters are added:
% * tuning.tol_constraint: tolerance on the constraints for validation.
% (see youla_lft_validation_1.m)
% * tuning.amp: the maximal size of the optimization parameters, to test the linearity
%   of T1 + T2 Q T3 w.r.t. Q.
% * tuning.zero_T4: see youla_lft_validation_1.m.
%
% puls_syn is the initial design frequency gridding (that will be refined inside the routine).
%
% specif and puls_specif describe the specifications.
% Hinfinity and H2 specifications are allowed.
% specif{i}.models = list of models, on which the spec. #i must be satisfied.
% If e.g. specif{i}.models = [1 2], the corresponding models are described by
% tab_delta(1,:) and tab_delta(2,:).
%
% list_poles is the list of poles of the basis of Q(s), see gene_basis.m.
%
% see comp_puls_valid.m for "valid".
%
%
% i_first_critical_model = 0 --> direct synthesis on the whole (small) gridding of models in tab_delta.
%                        > 0 --> iterative synthesis on the (large) gridding of models in tab_delta, i.e.
%                                a gridding of worst-case models, used for the design, is iteratively refined.
%                                The first critical model is chosen as "i_first_critical_model".
%
% The output argument "list_critical_models" gives the list of critical models used for the design
%
% is_linearity_test = 0 --> No test of the linearity of T1 + T2 Q T3
%                     1 --> One preliminary test
%                     2 --> One preliminary test + On-line tests with the optimal controller
%
% If there are only H2 specifications, no linearity test is performed even when is_linearity_test > 0
%
% first_figure is the number of the first figure produced by the routine.
%
% sys_Q is the optimal value of Q(s).
%
% alfa_opt is the minimized objective.
%
% OK_design = 1 / 0 --> success or not of the optimization.
%
% puls_valid{i} = frequency gridding for validation on model # i
%
% The last input argument "subgradients" is optional. See optim_new.m for its meaning.
%
