function [tab_bnds,tab_wc_model]=youla_lft_validation_2...
         (youla,sys_Q,specif,puls_specif,alfa_opt,valid,first_figure,tab_delta_valid)
%
% call:  [tab_bnds,tab_wc_model]=youla_lft_validation_2...
%        (youla,sys_Q,specif,puls_specif,alfa_opt,valid,first_figure,tab_delta_valid)
%
% Validation of the controller on the closed loop LFT continuum,
% when the structured model perturbation Delta belongs to the unit ball.
%
% see youla_lft_design_one_shot.m for the input argument "youla"
%
% sys_Q (with ss format) is the current value of Q(s)
%
% specif and puls_specif describe the design specifications.
% ONLY HINFINITY SPECIFICATIONS, i.e. specif{i}.obj = 0 or 1.
% specif{i}.interp = 1 is not allowed.
%
% N.B.: rectangular performance blocks are not allowed in mu_margin.m, only square ones.
%
% alfa_opt is the minimized value of the objective.
% alfa_opt = Inf is allowed.
%
% see comp_puls_valid.m for the input argument "valid".
%
% first_figure is the number of the first figure that is produced by the routine.
%
% tab_delta_valid is used to compute a lower bound of the worst-case performance level
% on the associated gridding of models.
% tab_delta_valid(j,:) = value of the parameters for model # j
%
% For spec. #i:
% * The worst-case normalized performance level is between tab_bnds(i,1) and tab_bnds(i,2).
% * tab_wc_model(i,:) is the value of the scheduling parameters for the worst-case model.
%
% The worst-case normalized performance level is the minimum value of gamma
% satisfying over Delta inside its unit ball:
%
% 1/ || H(j omega,Delta) || <= gamma * template(omega)
%
% if the spec is the following constraint:
%
% || H(j omega,Delta) || <= template(omega)
%
% 2/ || H(j omega,Delta) || <= gamma * alfa_opt * template(omega)
%
% if the spec is the minimization of alfa under the following constraint:
%
% || H(j omega,Delta) || <= alfa * template(omega)
%
% If alfa_opt = Inf as an input argument, alfa_opt = 1 is chosen inside the routine
% for the definition of the worst-case normalized performance level.
%
% Main external subroutines: youla_lft_validation_1.m, mu_margin.m (from the Skew Mu Toolbox)
%
